## steamstore.py
A Python wrapper for the Public Steam StoreFront API

### Installation

1. Install with pip
   ```sh
   pip/pip3 install steamstore.py
   ```

--- 
1. Install via setup.py
   ```sh
   git clone https://github.com/saucesteals/steamstore.py.git
   ```
2. CD into the directory and install the package
   ```sh
   python/python3 setup.py
   ```




## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request


## License

Distributed under the MIT License. See `LICENSE` for more information.